Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp	(revision 64755)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIApplianceEditorWidget.cpp	(revision 64756)
@@ -159,5 +159,5 @@
 
     /** Constructs item passing @a iNumber and @a pParentItem to the base-class.
       * @param  enmType              Brings the Virtual System Description type.
       * @param  strRef               Brings something totally useless.
       * @param  strOrigValue         Brings the original value.
@@ -165,5 +165,5 @@
       * @param  strExtraConfigValue  Brings the extra configuration value. */
     UIVirtualHardwareItem(int iNumber,
-                          KVirtualSystemDescriptionType enmType,
+                          KVirtualSystemDescriptionType enmVSDType,
                           const QString &strRef,
                           const QString &strOrigValue,
@@ -199,5 +199,5 @@
 
     /** Holds the Virtual System Description type. */
-    KVirtualSystemDescriptionType  m_enmType;
+    KVirtualSystemDescriptionType  m_enmVSDType;
     /** Holds something totally useless. */
     QString                        m_strRef;
@@ -335,5 +335,5 @@
 
 UIVirtualHardwareItem::UIVirtualHardwareItem(int iNumber,
-                                             KVirtualSystemDescriptionType enmType,
+                                             KVirtualSystemDescriptionType enmVSDType,
                                              const QString &strRef,
                                              const QString &aOrigValue,
@@ -342,5 +342,5 @@
                                              UIApplianceModelItem *pParentItem)
     : UIApplianceModelItem(iNumber, ApplianceModelItemType_VirtualHardware, pParentItem)
-    , m_enmType(enmType)
+    , m_enmVSDType(enmVSDType)
     , m_strRef(strRef)
     , m_strOrigValue(aOrigValue)
@@ -359,26 +359,26 @@
     {
         /* Some items are checkable */
-        if (m_enmType == KVirtualSystemDescriptionType_Floppy ||
-            m_enmType == KVirtualSystemDescriptionType_CDROM ||
-            m_enmType == KVirtualSystemDescriptionType_USBController ||
-            m_enmType == KVirtualSystemDescriptionType_SoundCard ||
-            m_enmType == KVirtualSystemDescriptionType_NetworkAdapter)
+        if (m_enmVSDType == KVirtualSystemDescriptionType_Floppy ||
+            m_enmVSDType == KVirtualSystemDescriptionType_CDROM ||
+            m_enmVSDType == KVirtualSystemDescriptionType_USBController ||
+            m_enmVSDType == KVirtualSystemDescriptionType_SoundCard ||
+            m_enmVSDType == KVirtualSystemDescriptionType_NetworkAdapter)
             enmFlags |= Qt::ItemIsUserCheckable;
         /* Some items are editable */
-        if ((m_enmType == KVirtualSystemDescriptionType_Name ||
-             m_enmType == KVirtualSystemDescriptionType_Product ||
-             m_enmType == KVirtualSystemDescriptionType_ProductUrl ||
-             m_enmType == KVirtualSystemDescriptionType_Vendor ||
-             m_enmType == KVirtualSystemDescriptionType_VendorUrl ||
-             m_enmType == KVirtualSystemDescriptionType_Version ||
-             m_enmType == KVirtualSystemDescriptionType_Description ||
-             m_enmType == KVirtualSystemDescriptionType_License ||
-             m_enmType == KVirtualSystemDescriptionType_OS ||
-             m_enmType == KVirtualSystemDescriptionType_CPU ||
-             m_enmType == KVirtualSystemDescriptionType_Memory ||
-             m_enmType == KVirtualSystemDescriptionType_SoundCard ||
-             m_enmType == KVirtualSystemDescriptionType_NetworkAdapter ||
-             m_enmType == KVirtualSystemDescriptionType_HardDiskControllerIDE ||
-             m_enmType == KVirtualSystemDescriptionType_HardDiskImage) &&
+        if ((m_enmVSDType == KVirtualSystemDescriptionType_Name ||
+             m_enmVSDType == KVirtualSystemDescriptionType_Product ||
+             m_enmVSDType == KVirtualSystemDescriptionType_ProductUrl ||
+             m_enmVSDType == KVirtualSystemDescriptionType_Vendor ||
+             m_enmVSDType == KVirtualSystemDescriptionType_VendorUrl ||
+             m_enmVSDType == KVirtualSystemDescriptionType_Version ||
+             m_enmVSDType == KVirtualSystemDescriptionType_Description ||
+             m_enmVSDType == KVirtualSystemDescriptionType_License ||
+             m_enmVSDType == KVirtualSystemDescriptionType_OS ||
+             m_enmVSDType == KVirtualSystemDescriptionType_CPU ||
+             m_enmVSDType == KVirtualSystemDescriptionType_Memory ||
+             m_enmVSDType == KVirtualSystemDescriptionType_SoundCard ||
+             m_enmVSDType == KVirtualSystemDescriptionType_NetworkAdapter ||
+             m_enmVSDType == KVirtualSystemDescriptionType_HardDiskControllerIDE ||
+             m_enmVSDType == KVirtualSystemDescriptionType_HardDiskImage) &&
             m_checkState == Qt::Checked) /* Item has to be enabled */
             enmFlags |= Qt::ItemIsEditable;
@@ -395,9 +395,9 @@
         {
             if (iColumn == ApplianceViewSection_ConfigValue &&
-                (m_enmType == KVirtualSystemDescriptionType_Floppy ||
-                 m_enmType == KVirtualSystemDescriptionType_CDROM ||
-                 m_enmType == KVirtualSystemDescriptionType_USBController ||
-                 m_enmType == KVirtualSystemDescriptionType_SoundCard ||
-                 m_enmType == KVirtualSystemDescriptionType_NetworkAdapter))
+                (m_enmVSDType == KVirtualSystemDescriptionType_Floppy ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_CDROM ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_USBController ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_SoundCard ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_NetworkAdapter))
             {
                 m_checkState = static_cast<Qt::CheckState>(value.toInt());
@@ -436,5 +436,5 @@
             if (iColumn == ApplianceViewSection_Description)
             {
-                switch (m_enmType)
+                switch (m_enmVSDType)
                 {
                     case KVirtualSystemDescriptionType_Name:                   value = UIApplianceEditorWidget::tr("Name"); break;
@@ -466,5 +466,5 @@
             else if (iColumn == ApplianceViewSection_ConfigValue)
             {
-                switch (m_enmType)
+                switch (m_enmVSDType)
                 {
                     case KVirtualSystemDescriptionType_Description:
@@ -501,5 +501,5 @@
             if (iColumn == ApplianceViewSection_Description)
             {
-                switch (m_enmType)
+                switch (m_enmVSDType)
                 {
                     case KVirtualSystemDescriptionType_Name:                   value = UIIconPool::iconSet(":/name_16px.png"); break;
@@ -528,5 +528,5 @@
             }
             else if (iColumn == ApplianceViewSection_ConfigValue &&
-                     m_enmType == KVirtualSystemDescriptionType_OS)
+                     m_enmVSDType == KVirtualSystemDescriptionType_OS)
             {
                 const QStyle *pStyle = QApplication::style();
@@ -562,9 +562,9 @@
         {
             if (iColumn == ApplianceViewSection_ConfigValue &&
-                (m_enmType == KVirtualSystemDescriptionType_Floppy ||
-                 m_enmType == KVirtualSystemDescriptionType_CDROM ||
-                 m_enmType == KVirtualSystemDescriptionType_USBController ||
-                 m_enmType == KVirtualSystemDescriptionType_SoundCard ||
-                 m_enmType == KVirtualSystemDescriptionType_NetworkAdapter))
+                (m_enmVSDType == KVirtualSystemDescriptionType_Floppy ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_CDROM ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_USBController ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_SoundCard ||
+                 m_enmVSDType == KVirtualSystemDescriptionType_NetworkAdapter))
                 value = m_checkState;
             break;
@@ -572,5 +572,5 @@
         case UIVirtualHardwareItem::TypeRole:
         {
-            value = m_enmType;
+            value = m_enmVSDType;
             break;
         }
@@ -590,5 +590,5 @@
     if (idx.column() == ApplianceViewSection_ConfigValue)
     {
-        switch (m_enmType)
+        switch (m_enmVSDType)
         {
             case KVirtualSystemDescriptionType_OS:
@@ -697,5 +697,5 @@
 {
     bool fDone = false;
-    switch (m_enmType)
+    switch (m_enmVSDType)
     {
         case KVirtualSystemDescriptionType_OS:
@@ -788,5 +788,5 @@
 {
     bool fDone = false;
-    switch (m_enmType)
+    switch (m_enmVSDType)
     {
         case KVirtualSystemDescriptionType_OS:
@@ -1279,5 +1279,5 @@
                 UIVirtualHardwareItem *hwItem = static_cast<UIVirtualHardwareItem*>(pItem);
                 /* The license type shouldn't be displayed */
-                if (m_aFilteredList.contains(hwItem->m_enmType))
+                if (m_aFilteredList.contains(hwItem->m_enmVSDType))
                     return false;
             }
@@ -1305,8 +1305,8 @@
 
     for (unsigned int i = 0; i < RT_ELEMENTS(s_aSortList); ++i)
-        if (pHwLeft->m_enmType == s_aSortList[i])
+        if (pHwLeft->m_enmVSDType == s_aSortList[i])
         {
             for (unsigned int a = 0; a <= i; ++a)
-                if (pHwRight->m_enmType == s_aSortList[a])
+                if (pHwRight->m_enmVSDType == s_aSortList[a])
                     return true;
             return false;
@@ -159,5 +159,5 @@
 
     /** Constructs item passing @a iNumber and @a pParentItem to the base-class.
-      * @param  enmType              Brings the Virtual System Description type.
+      * @param  enmVSDType           Brings the Virtual System Description type.
       * @param  strRef               Brings something totally useless.
       * @param  strOrigValue         Brings the original value.
